Skip to contents

A species lookup table generated from survdat::get_species()

Usage

species

Format

A data frame with 2047 rows and 21 variables:

SCINAME

character Scientific name of specimen.

COMNAME

character Accepted common name of a fish or invertebrate species.

SVSPP

integer A standard code which represents a species caught in a trawl or dredge.

SVABBR

character Abbreviation of common name of specimen.

PYSPP

double Prey species name.

PYABBR

character Prey abbreviation.

NODCCODE

character National Oceanographic Data Center (NODC) taxononic code for species.

NODCTYPE

logical National Oceanographic Data Center (NODC) Type name code: S-scientific name, C-Common name

NODCLEVL

character National Oceanographic Data Center (NODC) taxanomic level: P-Phylum, C-Class, O-Order, F-Family, G-Genus, S-Species

NODCCTRL

character National Oceanographic Data Center (NODC).

NODCAUTH

character NODC code author (person who described species).

AUTHOR

character Author of document.

PICTURE

character Citation for picture of species.

COMMNT

character Comment related to species in SVDBS.SVSPECIES_LIST.

O_SVSCNM

character Former scientific name used by Survey branch.

O_SVCONM

character Former common name used by Survey branch.

O_SVSPP

integer Former species code.

DOC

character Date when the current record was updated or changed. Date format (MM/DD/YY HH:MI:SS)

UOC

character The Oracle username of the individual who changed the current record.

DOE

character Date when record was inserted into Oracle. Date format (MM/DD/YY HH:MI:SS).

UOE

character The Oracle username of the individual who entered the new record.