A species lookup table generated from survdat::get_species()
Format
A data frame with 2047 rows and 21 variables:
SCINAMEcharacter Scientific name of specimen.
COMNAMEcharacter Accepted common name of a fish or invertebrate species.
SVSPPinteger A standard code which represents a species caught in a trawl or dredge.
SVABBRcharacter Abbreviation of common name of specimen.
PYSPPdouble Prey species name.
PYABBRcharacter Prey abbreviation.
NODCCODEcharacter National Oceanographic Data Center (NODC) taxononic code for species.
NODCTYPElogical National Oceanographic Data Center (NODC) Type name code: S-scientific name, C-Common name
NODCLEVLcharacter National Oceanographic Data Center (NODC) taxanomic level: P-Phylum, C-Class, O-Order, F-Family, G-Genus, S-Species
NODCCTRLcharacter National Oceanographic Data Center (NODC).
NODCAUTHcharacter NODC code author (person who described species).
AUTHORcharacter Author of document.
PICTUREcharacter Citation for picture of species.
COMMNTcharacter Comment related to species in SVDBS.SVSPECIES_LIST.
O_SVSCNMcharacter Former scientific name used by Survey branch.
O_SVCONMcharacter Former common name used by Survey branch.
O_SVSPPinteger Former species code.
DOCcharacter Date when the current record was updated or changed. Date format (MM/DD/YY HH:MI:SS)
UOCcharacter The Oracle username of the individual who changed the current record.
DOEcharacter Date when record was inserted into Oracle. Date format (MM/DD/YY HH:MI:SS).
UOEcharacter The Oracle username of the individual who entered the new record.